<?php 
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

require_once ("mssql_database.php");
require_once ("mysql_database.php");

/**
 * The method retrieves information for the database connection
 * from a configuration file. The name of the config file should
 * be, database_config.xml, and it should be in the same directory
 * as this file.
 * @return non NULL value (ConnectionInfo object), upon successfull 
 * execution, and NULL if some information regarding the 
 * connection is not available.
 */

define ("RDBMS_TYPE_MSSQL", "mssql");
define ("RDBMS_TYPE_MYSQL", "mysql");

function GetConnectionInfo()
{
	$doc = new DOMDocument();
	$result = $doc->load('../resources/conf/database_config.xml');

	$server = $doc->getElementsByTagName("server")->item(0)->nodeValue;
	$user = $doc->getElementsByTagName("user")->item(0)->nodeValue;
	$password = $doc->getElementsByTagName("password")->item(0)->nodeValue;
	$database = $doc->getElementsByTagName("database")->item(0)->nodeValue;
	$type = $doc->getElementsByTagName("type")->item(0)->nodeValue;

	if ($server == NULL || $user == NULL || $password == NULL || $database == NULL || $type == NULL)
	{
		error_log ("SERVER, USER, PASSWORD OR DATABASE IS NULL\n");
	}
	else
	{
		$ConnInfo = new ConnectionInfo();
		$ConnInfo->server = $server;
		$ConnInfo->user = $user;
		$ConnInfo->password = $password;
		$ConnInfo->database = $database;
		$ConnInfo->type = $type;
	}
	return $ConnInfo;
}

/**
 * This method will load the configurations using GetConnectionInfo method and then creates 
 * correct database connection using the configurations 
 */
function GetDatabase()
{
	$connInfo = GetConnectionInfo();
	if($connInfo != NULL)
	{
		if($connInfo->type == RDBMS_TYPE_MSSQL)
		{	
			$db = new MSSQLDatabase($connInfo);
		}
		else
		{
			$db = new MySQLDatabase($connInfo);
		}
		$db->ConnectToDatabase();
		return $db;
	}
}

?>
